# eric7.PipInterface.PipLicensesDialog

Module implementing a dialog to show the licenses of an environment.

### Global Attributes

None

### Classes

PipLicensesDialog | Class implementing a dialog to show the licenses of an environment.

### Functions

None

## PipLicensesDialog

Class implementing a dialog to show the licenses of an environment.

### Derived from

QDialog, Ui_PipLicensesDialog

### Class Attributes

LicensesLicenseColumn
LicensesPackageColumn
LicensesVersionColumn
SummaryCountColumn
SummaryLicenseColumn

### Class Methods

None

### Methods

PipLicensesDialog | Constructor
__filterPackagesByLicense | Private slot to filter the list of packages by license.
__populateLicenses | Private slot to populate the license lists.
__saveAsCSV | Private slot to save the license information as a CSV file.

### Static Methods

None

#### PipLicensesDialog (Constructor)

PipLicensesDialog(pip, environment, packages=None, parent=None)

Constructor

pip (Pip)
  reference to the pip interface object
environment (str)
  name of the environment to show the licenses for
packages (list (optional))
  list of packages to show licenses for (or None to show all licenses (defaults to None)
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### PipLicensesDialog.__filterPackagesByLicense

__filterPackagesByLicense(licenseName)

Private slot to filter the list of packages by license.

licenseName (str)
  license name

#### PipLicensesDialog.__populateLicenses

__populateLicenses()

Private slot to populate the license lists.

#### PipLicensesDialog.__saveAsCSV

__saveAsCSV()

Private slot to save the license information as a CSV file.

Up